@@ -373,7 +373,7 @@ def test_passing_of_json_pdt_and_json_flags():
 def test_version_option():
     options = ["--version"]
     result = run_cli(options=options)
-    assert "0.9.2" in result.output
+    assert "0.9.3" in result.output
 
 
 def test_passing_of_netrc_file_that_does_not_exist():
@@ -399,18 +399,12 @@ def test_passing_of_no_json_output_flag():
 
 def test_passing_of_no_os():
     options = ["--specifier", "foo", "--json", "-", "--python-version", "38"]
-    message = "No operating system"
-    result = run_cli(options=options, expected_rc=1, get_env=False)
-    if message:
-        assert message in result.output
+    run_cli(options=options, expected_rc=2, get_env=False)
 
 
 def test_passing_of_no_pyver():
     options = ["--specifier", "foo", "--json", "-", "--operating-system", "linux"]
-    message = "No python version"
-    result = run_cli(options=options, expected_rc=1, get_env=False)
-    if message:
-        assert message in result.output
+    run_cli(options=options, expected_rc=2, get_env=False)
 
 
 def test_passing_of_wrong_pyver():
